==> percona-server-mongodb_4.0.9.orig.tar.gz: percona-server-mongodb-4.0.9-4/src/mongo/client/remote_command_targeter_factory.h <==

/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include <memory>

#include "mongo/base/disallow_copying.h"

namespace mongo {

class ConnectionString;
class RemoteCommandTargeter;

/**
 * Constructs RemoteCommandTargeters based on the specific type of the target (standalone,
 * replica set, etc).
 */
class RemoteCommandTargeterFactory {
    MONGO_DISALLOW_COPYING(RemoteCommandTargeterFactory);

public:
    virtual ~RemoteCommandTargeterFactory() = default;

    /**
     * Instantiates a RemoteCommandTargeter for the specified connection string.
     */
    virtual std::unique_ptr<RemoteCommandTargeter> create(const ConnectionString& connStr) = 0;

protected:
    RemoteCommandTargeterFactory() = default;
};

}  // namespace mongo

==> percona-server-mongodb_5.0.9.orig.tar.gz: percona-server-mongodb-5.0.9-8/src/mongo/client/remote_command_targeter_factory.h <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/client/remote_command_targeter.h"

namespace mongo {

/**
 * Constructs RemoteCommandTargeters based on the specific type of the target (standalone,
 * replica set, etc).
 */
class RemoteCommandTargeterFactory {
    RemoteCommandTargeterFactory(const RemoteCommandTargeterFactory&) = delete;
    RemoteCommandTargeterFactory& operator=(const RemoteCommandTargeterFactory&) = delete;

public:
    virtual ~RemoteCommandTargeterFactory() = default;

    /**
     * Instantiates a RemoteCommandTargeter for the specified connection string.
     */
    virtual std::unique_ptr<RemoteCommandTargeter> create(const ConnectionString& connStr) = 0;

protected:
    RemoteCommandTargeterFactory() = default;
};

}  // namespace mongo
